@@ -1,4 +1,4 @@
-// $Id: VideoControlPage.cpp,v 1.32 2005/05/13 14:11:03 h_oudejans Exp $
+// $Id: VideoControlPage.cpp 9266 2009-02-26 23:36:58Z mthuurne $
 // VideoControlPage.cpp: implementation of the VideoControlPage class.
 //
 //////////////////////////////////////////////////////////////////////
@@ -25,10 +25,12 @@
 IMPLEMENT_CLASS(VideoControlPage, wxPanel)
 BEGIN_EVENT_TABLE(VideoControlPage, wxPanel)
 	EVT_COMBOBOX(XRCID("RendererSelector"),CatapultPage::OnClickCombo)
-	EVT_COMBOBOX(XRCID("ScalerSelector"),CatapultPage::OnClickCombo)
+	EVT_COMBOBOX(XRCID("ScalerAlgoSelector"),CatapultPage::OnClickCombo)
+	EVT_COMBOBOX(XRCID("ScalerFactorSelector"),CatapultPage::OnClickCombo)
 	EVT_COMBOBOX(XRCID("AccuracySelector"),CatapultPage::OnClickCombo)
 	EVT_TEXT(XRCID("RendererSelector"),VideoControlPage::OnChangeRenderer)
-	EVT_TEXT(XRCID("ScalerSelector"),VideoControlPage::OnChangeScaler)
+	EVT_TEXT(XRCID("ScalerAlgoSelector"),VideoControlPage::OnChangeScalerAlgo)
+	EVT_TEXT(XRCID("ScalerFactorSelector"),VideoControlPage::OnChangeScalerFactor)
 	EVT_TEXT(XRCID("AccuracySelector"),VideoControlPage::OnChangeAccuracy)
 	EVT_TOGGLEBUTTON(XRCID("DeInterlaceButton"),VideoControlPage::OnDeInterlace)
 	EVT_TOGGLEBUTTON(XRCID("LimitSpriteButton"),VideoControlPage::OnLimitSprites)
@@ -60,7 +62,9 @@ VideoControlPage::VideoControlPage(wxWindow * parent, openMSXController * contro
 	wxXmlResource::Get()->LoadPanel(this, parent, wxT("VideoControlPage"));
 	m_controller = controller;
 	m_rendererList = (wxComboBox *)FindWindowByName(wxT("RendererSelector"));;
-	m_scalerList = (wxComboBox *)FindWindowByName(wxT("ScalerSelector"));
+	m_scalerAlgoList = (wxComboBox *)FindWindowByName(wxT("ScalerAlgoSelector"));
+	m_timesLabel = (wxStaticText *)FindWindowByName(wxT("times"));
+	m_scalerFactorList = (wxComboBox *)FindWindowByName(wxT("ScalerFactorSelector"));
 	m_accuracyList = (wxComboBox*)FindWindowByName(wxT("AccuracySelector"));
 	m_deinterlaceButton = (wxToggleButton*)FindWindowByName(wxT("DeInterlaceButton"));
 	m_limitSpritesButton = (wxToggleButton*)FindWindowByName(wxT("LimitSpriteButton"));
@@ -89,7 +93,7 @@ VideoControlPage::VideoControlPage(wxWindow * parent, openMSXController * contro
 	m_defaultGlow = wxT("");
 	m_defaultGamma = wxT("");
 	m_defaultScanline = wxT("");
-	
+
 	m_rendererLabel = (wxStaticText *)FindWindowByName(wxT("RendererLabel"));
 	m_scalerLabel = (wxStaticText *)FindWindowByName(wxT("ScalerLabel"));
 	m_accuracyLabel = (wxStaticText *)FindWindowByName(wxT("AccuracyLabel"));
@@ -100,6 +104,8 @@ VideoControlPage::VideoControlPage(wxWindow * parent, openMSXController * contro
 	m_blurLabel = (wxStaticText *)FindWindowByName(wxT("BlurLabel"));
 	m_glowLabel = (wxStaticText *)FindWindowByName(wxT("GlowLabel"));
 	m_gammaLabel = (wxStaticText *)FindWindowByName(wxT("GammaLabel"));
+
+	setNewRenderersAndScalers();
 }
 
 VideoControlPage::~VideoControlPage()
@@ -111,19 +117,24 @@ void VideoControlPage::OnChangeRenderer(wxCommandEvent &event)
 	m_controller->WriteCommand(wxString(wxT("set renderer ") + m_rendererList->GetValue()));
 }
 
-void VideoControlPage::OnChangeScaler(wxCommandEvent &event)
+void VideoControlPage::OnChangeScalerAlgo(wxCommandEvent &event)
 {
-	m_controller->WriteCommand(wxString(wxT("set scaler ") + m_scalerList->GetValue().Lower()));
+	m_controller->WriteCommand(wxString(wxT("set scale_algorithm ") + m_scalerAlgoList->GetValue().Lower()));
+}
+
+void VideoControlPage::OnChangeScalerFactor(wxCommandEvent &event)
+{
+	m_controller->WriteCommand(wxString(wxT("set scale_factor ") + m_scalerFactorList->GetValue().Lower()));
 }
 
 void VideoControlPage::OnChangeAccuracy(wxCommandEvent &event)
 {
 	m_controller->WriteCommand(wxString(wxT("set accuracy ") + m_accuracyList->GetValue().Lower()));
-} 
+}
 
 void VideoControlPage::OnDeInterlace(wxCommandEvent &event)
 {
-	wxToggleButton * button = (wxToggleButton *)event.m_eventObject;
+	wxToggleButton * button = (wxToggleButton *)event.GetEventObject();
 	if (button->GetValue())
 	{
 		m_controller->WriteCommand (wxT("set deinterlace on"));
@@ -133,12 +144,12 @@ void VideoControlPage::OnDeInterlace(wxCommandEvent &event)
 	{
 		m_controller->WriteCommand (wxT("set deinterlace off"));
 		button->SetLabel(wxT("Off"));
-	}			
+	}
 }
 
 void VideoControlPage::OnLimitSprites(wxCommandEvent &event)
 {
-	wxToggleButton * button = (wxToggleButton *)event.m_eventObject;
+	wxToggleButton * button = (wxToggleButton *)event.GetEventObject();
 	if (button->GetValue())
 	{
 		m_controller->WriteCommand (wxT("set limitsprites on"));
@@ -153,7 +164,7 @@ void VideoControlPage::OnLimitSprites(wxCommandEvent &event)
 
 void VideoControlPage::OnFullScreen(wxCommandEvent &event)
 {
-	wxToggleButton * button = (wxToggleButton *)event.m_eventObject;
+	wxToggleButton * button = (wxToggleButton *)event.GetEventObject();
 	FullScreenDlg dlg;
 	dlg.Center();
 	ConfigurationData * config = ConfigurationData::instance();
@@ -168,7 +179,7 @@ void VideoControlPage::OnFullScreen(wxCommandEvent &event)
 	else{
 		doIt = true;
 	}
-	
+
 	if (doIt) {
 		if (button->GetValue())
 		{
@@ -180,7 +191,7 @@ void VideoControlPage::OnFullScreen(wxCommandEvent &event)
 		}
 		else
 		{
-		
+
 			m_controller->WriteCommand (wxT("set fullscreen off"));
 			button->SetLabel(wxT("Off"));
 #ifdef __WXMSW__
@@ -200,7 +211,7 @@ void VideoControlPage::OnChangeBlur(wxScrollEvent &event)
 	wxString text;
 	text.sprintf(wxT("%ld"), event.GetInt());
 	m_blurIndicator->SetValue(text);
-	m_controller->WriteCommand (wxString(wxT("set blur ")) + text);	
+	m_controller->WriteCommand (wxString(wxT("set blur ")) + text);
 }
 
 void VideoControlPage::OnChangeGlow(wxScrollEvent &event)
@@ -261,7 +272,7 @@ void VideoControlPage::OnInputBlur(wxCommandEvent &event)
 		}
 		if (num >= 0) {
 			m_controller->WriteCommand (wxString(wxT("set blur ")) + text);
-			m_blurSlider->SetValue(num);	
+			m_blurSlider->SetValue(num);
 		}
 	}
 }
@@ -281,7 +292,7 @@ void VideoControlPage::OnInputGlow(wxCommandEvent &event)
 		}
 		if (num >= 0)
 		{
-			m_controller->WriteCommand (wxString(wxT("set glow ")) + text);	
+			m_controller->WriteCommand (wxString(wxT("set glow ")) + text);
 			m_glowSlider->SetValue(num);
 		}
 	}
@@ -347,7 +358,9 @@ void VideoControlPage::SetControlsOnLaunch()
 	m_scanlineIndicator->Enable(true);
 	m_defaultScanlineButton->Enable(true);
 	m_rendererList->Enable(true);
-	m_scalerList->Enable(true);
+	m_scalerAlgoList->Enable(true);
+	m_timesLabel->Enable(true);
+	m_scalerFactorList->Enable(true);
 	m_accuracyList->Enable(true);
 	m_deinterlaceButton->Enable(true);
 	m_limitSpritesButton->Enable(true);
@@ -389,7 +402,9 @@ void VideoControlPage::SetControlsOnEnd()
 	m_scanlineIndicator->Enable(false);
 	m_defaultScanlineButton->Enable(false);
 	m_rendererList->Enable(false);
-	m_scalerList->Enable(false);
+	m_scalerAlgoList->Enable(false);
+	m_timesLabel->Enable(false);
+	m_scalerFactorList->Enable(false);
 	m_accuracyList->Enable(false);
 	m_deinterlaceButton->Enable(false);
 	m_limitSpritesButton->Enable(false);
@@ -420,9 +435,14 @@ void VideoControlPage::FillRenderers(wxString renderers)
 	FillComboBox (wxT("RendererSelector"), renderers);
 }
 
-void VideoControlPage::FillScalers(wxString scalers)
+void VideoControlPage::FillScalerAlgos(wxString scalerAlgos)
 {
-	FillComboBox (wxT("ScalerSelector"), scalers);
+	FillComboBox (wxT("ScalerAlgoSelector"), scalerAlgos);
+}
+
+void VideoControlPage::FillScalerFactors(wxString scalerFactors)
+{
+	FillComboBox (wxT("ScalerFactorSelector"), scalerFactors);
 }
 
 void VideoControlPage::FillAccuracy(wxString accuracy)
@@ -432,7 +452,7 @@ void VideoControlPage::FillAccuracy(wxString accuracy)
 
 
 void VideoControlPage::FillComboBox (wxString control, wxString contents)
-{	
+{
 	wxComboBox * box = (wxComboBox *)FindWindowByName(control);
 	int pos;
 	box->Clear();
@@ -443,7 +463,7 @@ void VideoControlPage::FillComboBox (wxString control, wxString contents)
 		if (pos != -1)
 		{
 			box->Append(temp.Left(pos));
-			temp = temp.Mid(pos + 1);					
+			temp = temp.Mid(pos + 1);
 		}
 	}while (pos !=-1);
 	if (!temp.IsEmpty()) { // not everything parsed ?
@@ -456,9 +476,14 @@ void VideoControlPage::SetRenderer (wxString value)
 	m_rendererList->SetSelection(m_rendererList->FindString(value));
 }
 
-void VideoControlPage::SetScaler (wxString value)
+void VideoControlPage::SetScalerAlgo (wxString value)
 {
-	m_scalerList->SetSelection(m_scalerList->FindString(value));	
+	m_scalerAlgoList->SetSelection(m_scalerAlgoList->FindString(value));
+}
+
+void VideoControlPage::SetScalerFactor (wxString value)
+{
+	m_scalerFactorList->SetSelection(m_scalerFactorList->FindString(value));
 }
 
 void VideoControlPage::SetAccuracy(wxString value)
@@ -517,18 +542,18 @@ void VideoControlPage::OnBrowseScreenShot(wxCommandEvent &event)
 		screenshotpath = screenshotpath.Left(screenshotpath.Length()-4); // remove extension
 		screenshotfile = filedlg.GetFilename();
 		screenshotfile = screenshotfile.Left(screenshotfile.Length()-4); // idem
-	
+
 		while ((screenshotfile.Right(countersize+1).IsNumber()) && (countersize <4)){
-			countersize++;			
+			countersize++;
 		}
 		wxString currentcounter = screenshotpath.Right(countersize);
 		currentcounter.Prepend(wxT("0000"));
-		currentcounter = currentcounter.Right(4);		
-		
+		currentcounter = currentcounter.Right(4);
+
 		m_screenShotFile->SetValue(screenshotpath.Left(screenshotpath.Length()-countersize));
 //		m_screenShotCounter->SetValue(currentcounter);
 
-	}	
+	}
 }
 
 void VideoControlPage::OnTakeScreenShot(wxCommandEvent &event)
@@ -554,7 +579,7 @@ int VideoControlPage::FindFirstFreeScreenshotFile(wxString prefix)
 		countString.sprintf(wxT("0000%d"),counter);
 		countString = countString.Right(4);
 		if (!wxFileExists(prefix + countString +wxT(".png"))){
-			found = true;			
+			found = true;
 		}
 	}while ((counter<9999) && (!found));
 	return counter;
@@ -580,3 +605,12 @@ void VideoControlPage::UpdateScreenshotCounter()
 		m_screenShotCounter->SetValue(countString);
 	}
 }
+
+void VideoControlPage::setNewRenderersAndScalers()
+{
+	m_rendererList->Clear();
+	m_scalerAlgoList->Clear();
+	m_scalerFactorList->Clear();
+	m_accuracyList->Clear();
+
+}
